@@ -960,6 +960,7 @@ def make_dashboard():
 
         color_discrete_sequence = px.colors.qualitative.Dark24
         color_discrete_map = None
+        color_category_orders = None
 
         if color_column is None:
             colors = None
@@ -974,13 +975,15 @@ def make_dashboard():
                 data[color_column] = Categorical(
                     data[color_column], ["Tropical", "Subtropics", "Temperate", "Cold"]
                 )
-                data = data.sort_values(by="Climate zone")
                 color_discrete_map = {
                     "Tropical": "IndianRed",
                     "Subtropics": "Peru",
                     "Temperate": "ForestGreen",
                     "Cold": "CadetBlue",
                 }
+                color_category_orders = {
+                    color_column: ["Tropical", "Subtropics", "Temperate", "Cold"]
+                }
                 colors = data[color_column].values
                 color_continuous_scale = None
                 tickvals = []
@@ -992,13 +995,15 @@ def make_dashboard():
                     data[color_column],
                     ["magmatic", "phreatomagmatic", "phreatic", "Unknown"],
                 )
-                data = data.sort_values(by=color_column)
                 color_discrete_map = {
                     "Unknown": "lightslategray",
                     "magmatic": "darkred",
                     "phreatomagmatic": "darkmagenta",
                     "phreatic": "teal",
                 }
+                color_category_orders = {
+                    color_column: ["Unknown", "magmatic", "phreatomagmatic", "phreatic"]
+                }
                 colors = data[color_column].values
                 color_continuous_scale = None
                 tickvals = []
@@ -1009,13 +1014,15 @@ def make_dashboard():
                 data[color_column] = Categorical(
                     data[color_column], ["Weak", "Distorted", "Strong", "Unknown"]
                 )
-                data = data.sort_values(by=color_column)
                 color_discrete_map = {
                     "Unknown": "lightslategray",
                     "Weak": "darkcyan",
                     "Distorted": "darkmagenta",
                     "Strong": "crimson",
                 }
+                color_category_orders = {
+                    color_column: ["Unknown", "Weak", "Distorted", "Strong"]
+                }
                 colors = data[color_column].values
                 color_continuous_scale = None
                 tickvals = []
@@ -1030,14 +1037,15 @@ def make_dashboard():
                 data[color_column] = data[color_column].cat.rename_categories(
                     {"0": "Flag 0", "1": "Flag 1", "2": "Flag 2", "-1": "n/a"}
                 )
-                data = data.sort_values(by=color_column)
-
                 color_discrete_map = {
                     "Flag 2": "firebrick",
                     "Flag 1": "lightcoral",
                     "Flag 0": "steelblue",
                     "n/a": "lightslategray",
                 }
+                color_category_orders = {
+                    color_column: ["Flag 2", "Flag 1", "Flag 0", "n/a"]
+                }
                 colors = data[color_column].values
                 color_continuous_scale = None
                 tickvals = []
@@ -1059,9 +1067,14 @@ def make_dashboard():
                             ((i + 1) / N, interp_rgb(col_list, i / N)),
                         )
                     ]
+
                     colors = color_column
                     tickvals = [(cmin + cstep / 2) + i * cstep for i in range(N)]
                     ticktext = [cmin + i for i in range(N)]
+                    if cmin == 0:
+                        color_continuous_scale[0] = (0.0, "rgb(200,200,200)")
+                        color_continuous_scale[1] = (1 / N, "rgb(200,200,200)")
+                        ticktext[0] = "Unknown"
                     range_color = [cmin, cmax]
 
                 else:
@@ -1116,15 +1129,8 @@ def make_dashboard():
             range_color = [cmin, cmax]
 
             step = 10 ** floor(np.log10(cmax - cmin))
-            print(
-                f"cmax - cmin = {cmax - cmin}, floor(np.log10(cmax - cmin)) = {floor(np.log10(cmax - cmin))}, step = {step}"
-            )
 
             tickvals = lin_steps(cmin, cmax, step=step)
-            print(
-                f"linear: min = {np.nanmin(colors)}, cmin = {cmin}, max = {np.nanmax(colors)}, cmax = {cmax}"
-            )
-            print(tickvals)
             ticktext = tickvals
 
         if color_column in categorical_columns:
@@ -1157,6 +1163,17 @@ def make_dashboard():
             lambda x: add_units(x, data_units[size_column])
         )
 
+        data["Q_value"] = data[Q_column].apply(
+            lambda x: sci_string(x, precision=2, start_sci=2)
+        )
+        data["Q_value"] = data["Q_value"].apply(
+            lambda x: add_units(x, data_units[Q_column])
+        )
+        data["H_value"] = data[H_column].apply(lambda x: float_string(x, precision=2))
+        data["H_value"] = data["H_value"].apply(
+            lambda x: add_units(x, data_units[H_column])
+        )
+
         if "Name" in available_columns:
             hovertitle = "Name"
         else:
@@ -1166,13 +1183,14 @@ def make_dashboard():
             x=Q_column,
             y=H_column,
             labels={
-                "MER": "Mass eruption rate (kg/s)",
-                "Plume height": "Column height (km a.v.l.)",
+                Q_column: f"{Q_column} ({data_units[Q_column]})",
+                H_column: f"{H_column} ({data_units[H_column]})",
             },
             log_x=True,
             opacity=0.5,
             color=colors,
             size=sizes,
+            category_orders=color_category_orders,
             color_discrete_sequence=color_discrete_sequence,
             color_discrete_map=color_discrete_map,
             color_continuous_scale=color_continuous_scale,
@@ -1180,25 +1198,28 @@ def make_dashboard():
             symbol="symbol",
             symbol_map="identity",
             hover_name="Name",  # if 'Name' in available_columns else 'Volcano',
-            hover_data=["Volcano", "color_value", "size_value"],
+            hover_data=["Volcano", "Q_value", "H_value", "color_value", "size_value"],
         )
 
         fig.layout.coloraxis.colorbar.title = color_column
-        hvtmp = "<b>%{hovertext}</b><br><br>Mass eruption rate = %{x} kg/s<br>Column height = %{y} km a.v.l.<br>"
+        hvtmp = "<b>%{hovertext}</b><br><br>"
+        hvtmp += f"{Q_column}" + " = %{customdata[1]}<br>"
+        hvtmp += f"{H_column}" + " = %{customdata[2]}<br>"
+
         if (
             size_column is not None
             and size_column != Q_column
             and size_column != H_column
         ):
 
-            hvtmp += size_column + " = %{customdata[2]} " + "<br>"
+            hvtmp += size_column + " = %{customdata[4]} " + "<br>"
         if (
             color_column is not None
             and color_column != size_column
             and color_column != Q_column
             and color_column != H_column
         ):
-            hvtmp += color_column + ": %{customdata[1]}"
+            hvtmp += color_column + ": %{customdata[3]}"
             # if color_column in categorical_columns:
             #     hvtmp += color_column+': %{customdata[1]}'
             # else:
@@ -1224,6 +1245,8 @@ def make_dashboard():
                     legend=dict(
                         title=color_column,
                         itemwidth=30,
+                        itemclick="toggleothers",
+                        itemdoubleclick="toggle",
                     )
                 )
         else:
@@ -1286,11 +1309,11 @@ def make_dashboard():
 
         dataset.set_vars(xvar=xvar, yvar=yvar)
 
-        data = dataset.data
+        data = dataset.data.copy()
         data.dropna(
             axis=0,
             how="any",
-            subset=[IVESPA.height_column, IVESPA.mer_column],
+            subset=[H_column, Q_column],
             inplace=True,
         )
 
@@ -1303,15 +1326,20 @@ def make_dashboard():
             x=Q_column,
             y=H_column,
             labels={
-                "MER": "Mass eruption rate (kg/s)",
-                "Plume height": "Column height (km a.v.l.)",
+                "MER": f"{Q_column} ({dataset.data_units[Q_column]})",
+                "Plume height": f"{H_column} ({dataset.data_units[H_column]})",
             },
             log_x=True,
             opacity=0.75,
             hover_name="Name",  # if 'Name' in available_columns else 'Volcano',
             hover_data=["Volcano", "mle_residuals"],
         )
-        hvtmp = "<b>%{hovertext}</b><br><br>Mass eruption rate (kg/s) = %{x}<br>Column height (km a.v.l.) = %{y}<br>"
+        hvtmp = (
+            "<b>%{hovertext}</b><br><br>"
+            + f"{Q_column} ({dataset.data_units[Q_column]})"
+            + " = %{x}"
+        )
+        hvtmp += "<br>" + f"{H_column} ({dataset.data_units[H_column]})" + " = %{y}<br>"
         hvtmp += "Linear regression residual = %{customdata[1]:.3f}<br><extra></extra>"
         data_fig.update_traces(hovertemplate=hvtmp)
         data_fig.update_traces(
@@ -1739,6 +1767,8 @@ def shade_rgb_color(color, p):
 def add_units(x, units, bracket=False):
     if x != "No data":
         unit_str = units_html(units)
+        if unit_str == "":
+            return x
         if bracket:
             unit_str = "(" + unit_str + ")"
         return x + " " + unit_str
